<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../../configdialog/lxqtconfigdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
</context>
<context>
    <name>LXQt::MessageBox</name>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="74"/>
        <source>LXQt Power Manager Error</source>
        <translation>Fejl ved LXQt strømstyring</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="74"/>
        <source>Hibernate failed.</source>
        <translation>Dvaletilstand mislykkedes.</translation>
    </message>
</context>
<context>
    <name>LXQt::NotificationPrivate</name>
    <message>
        <location filename="../../lxqtnotification.cpp" line="152"/>
        <source>Notifications Fallback</source>
        <translation>Reserve for notifikation</translation>
    </message>
</context>
<context>
    <name>LXQt::PowerManager</name>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="117"/>
        <source>Hibernate</source>
        <translation>Dvale</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="124"/>
        <source>Suspend</source>
        <translation>Slumre</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="131"/>
        <source>Reboot</source>
        <translation>Genstart</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="138"/>
        <source>Shutdown</source>
        <translation>Luk ned</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="145"/>
        <source>Logout</source>
        <translation>Log ud</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="157"/>
        <source>LXQt Session Suspend</source>
        <translation>Slumretilstand af LXQt-session</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="158"/>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Vil du virkelig sætte din computer i slumretilstand?&lt;p&gt;Slumretilstand sætter computeren i energispare tilstand. Systemtilstanden mistes hvis strømmen forsvinder.</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="167"/>
        <source>LXQt Session Hibernate</source>
        <translation>LXQt Session Dvale</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="168"/>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Vil du virkelig sætte din computer i dvaletilstand?&lt;p&gt;Dvaletilstand sætter computeren i energispare tilstand. Systemtilstanden bibeholdes hvis strømmen forsvinder.</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="177"/>
        <source>LXQt Session Reboot</source>
        <translation>Genstart af LXQt-session</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="178"/>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Vil du virkelig genstarte din computer? Alt arbejde der ikke er blevet gemt, vil gå tabt...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="187"/>
        <source>LXQt Session Shutdown</source>
        <translation>Nedlukning af LXQt-session</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="188"/>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Vil du virkelig slukke din computer? Alt arbejde der ikke er blevet gemt, vil gå tabt...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="197"/>
        <source>LXQt Session Logout</source>
        <translation>Udlogning af LXQt-session</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="198"/>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Vil du virkelig logge ud? Alt arbejde der ikke er blevet gemt, vil gå tabt...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="206"/>
        <location filename="../../lxqtpowermanager.cpp" line="211"/>
        <source>LXQt Power Manager Error</source>
        <translation>Fejl ved LXQt strømstyring</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="206"/>
        <source>Hibernate failed.</source>
        <translation>Dvaletilstand mislykkedes.</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="211"/>
        <source>Suspend failed.</source>
        <translation>Slumretilstand mislykkedes.</translation>
    </message>
</context>
<context>
    <name>LXQt::ScreenSaver</name>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="236"/>
        <source>Lock Screen</source>
        <translation>Lås skærm</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="156"/>
        <source>Screen Saver Error</source>
        <translation>Fejl ved pauseskærm</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="162"/>
        <location filename="../../lxqtscreensaver.cpp" line="168"/>
        <location filename="../../lxqtscreensaver.cpp" line="175"/>
        <source>Screen Saver Activation Error</source>
        <translation>Fejl ved aktivering af pauseskærm</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="176"/>
        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver: %1.</source>
        <translation>Fejl ved start af pauseskærm. Ukendt fejl - udokumenteret værdi fra xdg-screensaver: %1.</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="157"/>
        <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
        <translation>Fejl ved start af pauseskærm. Syntaksfejl i argumenter til xdg-screensaver.</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="163"/>
        <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
        <translation>Fejl ved start af pauseskærm. Sørg for at du har xscreensaver installeret og kørende.</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="169"/>
        <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
        <translation>Fejl ved start af pauseskærm. Handling &apos;aktivér&apos; mislykkedes. Sørg for at du har xscreensaver installeret og kørende.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="87"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="137"/>
        <source>Power Manager Error</source>
        <translation>Fejl ved strømstyring</translation>
    </message>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="88"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="138"/>
        <source>QDBusInterface is invalid</source>
        <translation>QDBusInterface er ugyldig</translation>
    </message>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="102"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="152"/>
        <source>Power Manager Error (D-BUS call)</source>
        <translation>Fejl ved strømstyring (D-BUS-kald)</translation>
    </message>
</context>
</TS>
